function [peakData, header] = hACQGetPeaks(instrument, timeout)
%function hACQGetPeaks(instrument, timeout)
%Returns a cell array containing the detected peaks for each channel.
%
%parameters:
%instrument - The tcp-ip object that is connected to the Hyperion Instrument.
%timeout - The requested timeout, in seconds.
%
%Return Values
%peakData - A cell array containing peak data for each channel.
%header - A structure with the following fields:
    %length - the length of the header, in bytes
    %version - the header version
    %serialNumber - the serialNumber of the scan.
    %timeStamp - A time stop, corresponding to the number of seconds that
    %have passed since 00:00:00 1/1/1970.
    %numPeaks - An array containing the number of peaks detected on each
    %channel.

response = hCOMMExecuteCommand(instrument, '#GetPeaks', '', 1, timeout);
dataBytes = response.content;
header.length = typecast(dataBytes(1:2),'uint16');
header.version = typecast(dataBytes(3:4),'uint16');
header.reserved = typecast(dataBytes(5:8),'uint32');
header.serialNumber = typecast(dataBytes(9:16),'uint64');
timeStampInt = typecast(dataBytes(17:20),'uint32');
timeStampFrac = typecast(dataBytes(21:24),'uint32');

header.timeStamp = uint64(double(timeStampInt)*1e9 + double(timeStampFrac));
header.numPeaks = typecast(dataBytes(25:56),'uint16');

peakDataBytes = dataBytes(header.length + 1:end);

allPeaks = typecast(peakDataBytes,'double');

index = 1;
channel = 1;
for chanPeaks = header.numPeaks'
    if chanPeaks > 0
        peakData{channel} = allPeaks(index:(index + chanPeaks - 1));
        index = index + chanPeaks;
    else
        peakData{channel} = [];
    end
    channel = channel + 1;
end
