function [calibrationOffsets, calibrationScale] = hACQGetPowerCalibrationInfo(instrument)
%function [calibrationOffsets, calibrationScale] = hACQGetPowerCalibrationInfo(instrument)
%Returns the calibration offset and scale for each channel.  These can be
%used to convert the returned fixed point spectrum into a floating point
%power level with units of dBm, using the following formula: 
%calibratedSpectrum = spectrum/scale + offset
%
%Parameters:
%instrument - The tcp-ip object that is connected to the Hyperion Instrument.
%
%Return values:
%calibrationOffsets - Array containing the calibration offset for each channel.
%calibrationScale - Array containing the calibration scale for each
%channel.
response = hCOMMExecuteCommand(instrument, '#GetPowerCalibrationInfo','',1,1);
data = double(typecast(response.content, 'int32'));
data = reshape(data',2,[]);
calibrationOffsets = data(1,:);
calibrationScale = data(2,:);
